@@ -26,23 +26,14 @@ class DetectController:
             raise Exception(res.text)
 
     @verify_credentials
-    def describe_activity(self, start: str, finish: str):
+    def describe_activity(self, filters: dict, view: str = 'logs'):
         """ Get report for an Account """
-        params = dict(start=start, finish=finish)
+        params = dict(view=view, **filters)
         res = requests.get(f'{self.account.hq}/detect/activity', headers=self.account.headers, params=params)
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
 
-    @verify_credentials
-    def list_probes(self, days=7):
-        """ Get all probes associated to an Account """
-        params = dict(days=days)
-        res = requests.get(f'{self.account.hq}/detect/probes', headers=self.account.headers, params=params)
-        if res.status_code == 200:
-            return res.json()
-        raise Exception(res.text)
-
     @verify_credentials
     def print_queue(self):
         res = requests.get(f'{self.account.hq}/detect/queue', headers=self.account.headers)
@@ -51,7 +42,7 @@ class DetectController:
         raise Exception(res.text)
 
     @verify_credentials
-    def enable_test(self, ident: str, run_code: int, tags: list):
+    def enable_test(self, ident: str, run_code: int, tags: str):
         """ Enable a test so endpoints will start running it """
         res = requests.post(
             url=f'{self.account.hq}/detect/queue/{ident}',
@@ -69,23 +60,14 @@ class DetectController:
             raise Exception(res.text)
 
     @verify_credentials
-    def stats(self, ident: str, days: int = 30):
-        """ Pull social statistics for a specific test """
-        params = dict(days=days)
-        res = requests.get(f'{self.account.hq}/detect/{ident}/social', headers=self.account.headers, params=params)
-        if res.status_code == 200:
-            return res.json()
-        raise Exception(res.text)
-
-    @verify_credentials
-    def observe(self, row_id, value):
-        """ Mark a result as observed """
-        params = dict(row_id=row_id, value=value)
-        res = requests.post(f'{self.account.hq}/detect/observe', headers=self.account.headers, json=params)
+    def decide(self, dhash: str, action: int):
+        """ Make a decision based on a result set """
+        params = dict(dhash=dhash, action=action)
+        res = requests.post(f'{self.account.hq}/detect/decide', headers=self.account.headers, json=params)
         if res.status_code == 200:
             return res.text
         raise Exception(res.text)
-
+    
     @verify_credentials
     def search(self, identifier: str):
         """ Search the NVD for a keyword """
@@ -102,3 +84,21 @@ class DetectController:
         if res.status_code == 200:
             return res.json()
         raise Exception(res.text)
+
+    @verify_credentials
+    def list_probes(self, days=7):
+        """ Get all probes associated to an Account """
+        params = dict(days=days)
+        res = requests.get(f'{self.account.hq}/detect/probes', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
+
+    @verify_credentials
+    def social_stats(self, ident: str, days: int = 30):
+        """ Pull social statistics for a specific test """
+        params = dict(days=days)
+        res = requests.get(f'{self.account.hq}/detect/{ident}/social', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
